S4 method do not validate entries, since it is not exported and the data is validated by the constructors. The validation here would be resource consuming.
Aggregate(aggregation.matrix, factor.evaluation, resource.evaluation,
factor.is.specific, nrfactors)
# S4 method for Aggregation.matrix.default,character,character,logical,numeric
Aggregate(aggregation.matrix,
factor.evaluation, resource.evaluation, factor.is.specific, nrfactors)
# S4 method for Aggregation.matrix.membership.difference,character,character,logical,numeric
Aggregate(aggregation.matrix,
factor.evaluation, resource.evaluation, factor.is.specific, nrfactors)
aggregation.matrix
character factor evaluation from project
character factor evaluation from option
logic indicates that this factor is specific for the project
numeric number of factors evaluated for each project/option
numeric indicate the result factor per option. If a specific factor is not achieved it returns -1