Learn R Programming

coppeCosenzaR (version 0.1.3)

Aggregation.matrix-class: Aggregation.matrix S4 Class

Description

This class was included to act as an abstract class to be inherited by concrete classes that implement their matrix in constructors.

Arguments

Slots

name

character