S4 method to construct Coppe.cosenza objects. The package also provides a way to verify the consistency of the entry data. There are 3 different matrices which are considered for the evaluation purposes: The project' s required factors; The project's description of specific factors; and the options' available level of factors. All the factors must be evaluated by each project and by each option. The program deconstruct each evaluation so as to verify: if all the factors are evaluated for each project; if all the factors are evaluated for each option, and besides, if all the linguistic variables are the prescribed ones. Such verification avoids incomplete or incorrect evaluations presenting the correspondent error messages.
Coppe.cosenza(x, y, factors.of.interest, aggregation.matrix.name = "default",
normalize = FALSE)# S4 method for ANY,ANY,ANY,ANY,ANY
Coppe.cosenza(x)
# S4 method for Project.portfolio,Option.portfolio,Factors.of.interest,missing,missing
Coppe.cosenza(x,
y, factors.of.interest, aggregation.matrix.name = "default",
normalize = FALSE)
# S4 method for Project.portfolio,Option.portfolio,Factors.of.interest,character,missing
Coppe.cosenza(x,
y, factors.of.interest, aggregation.matrix.name = "default",
normalize = FALSE)
# S4 method for Project.portfolio,Option.portfolio,Factors.of.interest,missing,logical
Coppe.cosenza(x,
y, factors.of.interest, aggregation.matrix.name = "default",
normalize = FALSE)
# S4 method for Project.portfolio,Option.portfolio,Factors.of.interest,character,logical
Coppe.cosenza(x,
y, factors.of.interest, aggregation.matrix.name = "default",
normalize = FALSE)
# S4 method for Project,ANY,ANY,ANY,ANY
Coppe.cosenza(x, y, factors.of.interest,
aggregation.matrix.name = "default", normalize = FALSE)
# S4 method for Project.portfolio,Option,ANY,ANY,ANY
Coppe.cosenza(x, y,
factors.of.interest, aggregation.matrix.name = "default",
normalize = FALSE)
Project.portfolio or Project S4 object
Option.portfolio or Option S4 object
Factors.of.interest S4 object
character - the name of Aggregation.matrix to be used. If not provided the "default" implementation will be used
logical - if TRUE, the values will be normalized, dividing results by the number of factors.
Coppe.cosenza S4 object