Learn R Programming

coppeCosenzaR (version 0.1.3)

Factor-class: Factor S4 Class

Description

Factor S4 class contains a single slot with the Factor name. A factor in the COPPE-Cosenza model represents an item to be considered both in the options and in projects.

Arguments

Slots

name

character