powered by
This function is a constructor to Project.criterion S4 class. It defines the criterion to be used in association to a factor when evaluating projects.
Project.criterion(factor, importance.degree, specific)
Factor S4 class
character, must mach one item of the scale of degrees to be used ("Cr", "C", "LC","I")
logical indicates the considered factors is specific for the project under consideration#'
a Project.criterion S4 object
Project.criterion
# NOT RUN { Project.criterion <- Project.criterion(factor, importance.degree, specific) # } # NOT RUN { Project.criterion(Factor("fator1"), "LC", FALSE) # }
Run the code above in your browser using DataLab