Learn R Programming

coppeCosenzaR (version 0.1.3)

Project.criterion-class: Project.criterion S4 Class

Description

Project.criterion S4 class. It defines the criterion to be used in association to a factor when evaluating projects.

Arguments

Slots

factor

Factor S4 class

importance.degree

character, must mach the scale of degrees to be used

specific

logical indicates the considered factors is specific for the project under consideration

Details

The accepted degrees are: "Cr", "C", "LC","I"