Learn R Programming

coppeCosenzaR (version 0.1.3)

as.data.frame: as.data.frame

Description

This S4 method masks the base::as.data.frame() S3 function. If a call uses parameters other then the expected by this package, then it will be forward to the S3 function.

Usage

as.data.frame(x, row.names, optional, ...)

# S4 method for Option.portfolio as.data.frame(x)

# S4 method for Project.portfolio as.data.frame(x, row.names = NA, optional = FALSE)

Arguments

x

Option.portfolio or Project.portfolio

row.names

not used. It is inherited from base::as.data.frame()

optional

logical. To be used with Project.portfolio. Indicates if the return is a data.frame with factor evaluations or with the information about which factors are specific to a project. The default is optional = FALSE

...

not used.

Value

data.frame

Examples

Run this code
# NOT RUN {
as.data.frame(option.portfolio)
# }
# NOT RUN {
# }
# NOT RUN {
as.data.frame(project.portfolio, option = TRUE)
# }
# NOT RUN {
as.data.frame(project.portfolio,  , TRUE)
# }
# NOT RUN {
as.data.frame(project.portfolio, ANY, FALSE)
# }
# NOT RUN {
as.data.frame(project.portfolio, option = FALSE)
# }
# NOT RUN {
as.data.frame(project.portfolio)
# }
# NOT RUN {
 This infer option is FALSE, too.

# }

Run the code above in your browser using DataLab