Learn R Programming

coppeCosenzaR (version 0.1.3)

getOptionFactorsNames: getOptionFactorsNames

Description

This function returns a sorted vector with all the factors names in a Option S4 object

Usage

getOptionFactorsNames(option)

Arguments

option

an Option S4 object

Value

It provides a sorted vector with the names of factors in an option.

Examples

Run this code
# NOT RUN {
getOptionFactorsNames(option)
# }
# NOT RUN {
# }

Run the code above in your browser using DataLab