powered by
This function returns a sorted vector with all the factors names in a Option S4 object
getOptionFactorsNames(option)
an Option S4 object
It provides a sorted vector with the names of factors in an option.
# NOT RUN { getOptionFactorsNames(option) # } # NOT RUN { # }
Run the code above in your browser using DataLab